@@ -25,7 +25,7 @@ from fanstatic import Library, Resource
 # import Zope3 packages
 
 # import local packages
-from ztfy.jqueryui.browser import jquery_jsonrpc, jquery_alerts
+from ztfy.jqueryui import jquery_jsonrpc, jquery_alerts
 
 
 library = Library('ztfy.security', 'resources')
